==> cdk-lambda-layer-node-proxy-agent-1.198.0-sources.jar: software/amazon/awscdk/lambda/layer/node/proxy/agent/NodeProxyAgentLayer.java <==
package software.amazon.awscdk.lambda.layer.node.proxy.agent;

/**
 * An AWS Lambda layer that includes the NPM dependency `proxy-agent`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.lambda.layer.node.proxy.agent.NodeProxyAgentLayer;
 * import software.amazon.awscdk.services.lambda.*;
 * Function fn;
 * fn.addLayers(new NodeProxyAgentLayer(this, "NodeProxyAgentLayer"));
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.74.0 (build 6d08790)", date = "2023-03-22T19:35:44.754Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.lambda.layer.node.proxy.agent.$Module.class, fqn = "@aws-cdk/lambda-layer-node-proxy-agent.NodeProxyAgentLayer")
public class NodeProxyAgentLayer extends software.amazon.awscdk.services.lambda.LayerVersion {

    protected NodeProxyAgentLayer(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected NodeProxyAgentLayer(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public NodeProxyAgentLayer(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }
}

==> cdk-lambda-layer-node-proxy-agent-1.204.0-sources.jar: software/amazon/awscdk/lambda/layer/node/proxy/agent/NodeProxyAgentLayer.java <==
package software.amazon.awscdk.lambda.layer.node.proxy.agent;

/**
 * An AWS Lambda layer that includes the NPM dependency <code>proxy-agent</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.lambda.layer.node.proxy.agent.NodeProxyAgentLayer;
 * import software.amazon.awscdk.services.lambda.*;
 * Function fn;
 * fn.addLayers(new NodeProxyAgentLayer(this, "NodeProxyAgentLayer"));
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:30:41.466Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.lambda.layer.node.proxy.agent.$Module.class, fqn = "@aws-cdk/lambda-layer-node-proxy-agent.NodeProxyAgentLayer")
public class NodeProxyAgentLayer extends software.amazon.awscdk.services.lambda.LayerVersion {

    protected NodeProxyAgentLayer(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected NodeProxyAgentLayer(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public NodeProxyAgentLayer(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }
}
